@@ -1,5 +1,4 @@
-"""Functional interface to graph methods and assorted utilities.
-"""
+"""Functional interface to graph methods and assorted utilities."""
 
 from collections import Counter
 from itertools import chain
@@ -31,8 +30,10 @@ __all__ = [
     "create_empty_copy",
     "set_node_attributes",
     "get_node_attributes",
+    "remove_node_attributes",
     "set_edge_attributes",
     "get_edge_attributes",
+    "remove_edge_attributes",
     "all_neighbors",
     "non_neighbors",
     "non_edges",
@@ -565,6 +566,7 @@ def create_empty_copy(G, with_data=True):
     return H
 
 
+@nx._dispatchable(preserve_node_attrs=True, mutates_input=True)
 def set_node_attributes(G, values, name=None):
     """Sets node attributes from a given value or dictionary of values.
 
@@ -666,6 +668,7 @@ def set_node_attributes(G, values, name=None):
     nx._clear_cache(G)
 
 
+@nx._dispatchable(node_attrs={"name": "default"})
 def get_node_attributes(G, name, default=None):
     """Get node attributes from graph
 
@@ -702,6 +705,44 @@ def get_node_attributes(G, name, default=None):
     return {n: d[name] for n, d in G.nodes.items() if name in d}
 
 
+@nx._dispatchable(preserve_node_attrs=True, mutates_input=True)
+def remove_node_attributes(G, *attr_names, nbunch=None):
+    """Remove node attributes from all nodes in the graph.
+
+    Parameters
+    ----------
+    G : NetworkX Graph
+
+    *attr_names : List of Strings
+        The attribute names to remove from the graph.
+
+    nbunch : List of Nodes
+        Remove the node attributes only from the nodes in this list.
+
+    Examples
+    --------
+    >>> G = nx.Graph()
+    >>> G.add_nodes_from([1, 2, 3], color="blue")
+    >>> nx.get_node_attributes(G, "color")
+    {1: 'blue', 2: 'blue', 3: 'blue'}
+    >>> nx.remove_node_attributes(G, "color")
+    >>> nx.get_node_attributes(G, "color")
+    {}
+    """
+
+    if nbunch is None:
+        nbunch = G.nodes()
+
+    for attr in attr_names:
+        for n, d in G.nodes(data=True):
+            if n in nbunch:
+                try:
+                    del d[attr]
+                except KeyError:
+                    pass
+
+
+@nx._dispatchable(preserve_edge_attrs=True, mutates_input=True)
 def set_edge_attributes(G, values, name=None):
     """Sets edge attributes from a given value or dictionary of values.
 
@@ -840,6 +881,7 @@ def set_edge_attributes(G, values, name=None):
     nx._clear_cache(G)
 
 
+@nx._dispatchable(edge_attrs={"name": "default"})
 def get_edge_attributes(G, name, default=None):
     """Get edge attributes from graph
 
@@ -882,6 +924,42 @@ def get_edge_attributes(G, name, default=None):
     return {x[:-1]: x[-1][name] for x in edges if name in x[-1]}
 
 
+@nx._dispatchable(preserve_edge_attrs=True, mutates_input=True)
+def remove_edge_attributes(G, *attr_names, ebunch=None):
+    """Remove edge attributes from all edges in the graph.
+
+    Parameters
+    ----------
+    G : NetworkX Graph
+
+    *attr_names : List of Strings
+        The attribute names to remove from the graph.
+
+    Examples
+    --------
+    >>> G = nx.path_graph(3)
+    >>> nx.set_edge_attributes(G, {(u, v): u + v for u, v in G.edges()}, name="weight")
+    >>> nx.get_edge_attributes(G, "weight")
+    {(0, 1): 1, (1, 2): 3}
+    >>> remove_edge_attributes(G, "weight")
+    >>> nx.get_edge_attributes(G, "weight")
+    {}
+    """
+    if ebunch is None:
+        ebunch = G.edges(keys=True) if G.is_multigraph() else G.edges()
+
+    for attr in attr_names:
+        edges = (
+            G.edges(keys=True, data=True) if G.is_multigraph() else G.edges(data=True)
+        )
+        for *e, d in edges:
+            if tuple(e) in ebunch:
+                try:
+                    del d[attr]
+                except KeyError:
+                    pass
+
+
 def all_neighbors(graph, node):
     """Returns all of the neighbors of a node in the graph.
 
@@ -987,6 +1065,7 @@ def common_neighbors(G, u, v):
     return G._adj[u].keys() & G._adj[v].keys() - {u, v}
 
 
+@nx._dispatchable(preserve_edge_attrs=True)
 def is_weighted(G, edge=None, weight="weight"):
     """Returns True if `G` has weighted edges.
 
@@ -1094,6 +1173,7 @@ def is_negatively_weighted(G, edge=None, weight="weight"):
     return any(weight in data and data[weight] < 0 for u, v, data in G.edges(data=True))
 
 
+@nx._dispatchable
 def is_empty(G):
     """Returns True if `G` has no edges.
 
@@ -1246,6 +1326,7 @@ def selfloop_edges(G, data=False, keys=False, default=None):
             return ((n, n) for n, nbrs in G._adj.items() if n in nbrs)
 
 
+@nx._dispatchable
 def number_of_selfloops(G):
     """Returns the number of selfloop edges.
 
